Documentation
¶
Index ¶
- type Cell
- func (c *Cell) AsBool() (bool, bool)
- func (c *Cell) AsNumber() (float64, bool)
- func (c *Cell) AsString() (string, bool)
- func (c *Cell) Bool() bool
- func (c *Cell) Col() int
- func (c *Cell) ColumnName() string
- func (c *Cell) IsEmpty() bool
- func (c *Cell) Number() float64
- func (c *Cell) String() string
- func (c *Cell) Time() (time.Time, bool)
- func (c *Cell) Type() CellType
- func (c *Cell) Value() string
- type CellRef
- type CellType
- type Row
- type Sheet
- func (s *Sheet) Cells() iter.Seq2[CellRef, *Cell]
- func (s *Sheet) Dimension() (firstRow, lastRow, firstCol, lastCol int, ok bool)
- func (s *Sheet) Name() string
- func (s *Sheet) NumRows() int
- func (s *Sheet) Row(i int) *Row
- func (s *Sheet) RowByNumber(n int) *Row
- func (s *Sheet) Rows() iter.Seq2[int, *Row]
- type Workbook
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Cell ¶
type Cell struct {
// contains filtered or unexported fields
}
Cell represents a single cell.
func (*Cell) ColumnName ¶
ColumnName returns the Excel column name (A, B, ..., Z, AA, AB).
type Row ¶
type Row struct {
// contains filtered or unexported fields
}
Row represents a row in a worksheet.
type Sheet ¶
type Sheet struct {
// contains filtered or unexported fields
}
Sheet represents a worksheet.
func (*Sheet) Dimension ¶
Dimension returns the sheet dimension bounds (inclusive). ok is false when no data or dimension is unavailable.
func (*Sheet) RowByNumber ¶
RowByNumber returns a row by its Excel row number, or nil if not found.
type Workbook ¶
type Workbook struct {
// contains filtered or unexported fields
}
Workbook represents an XLS workbook.
func OpenReader ¶
func OpenReader(r io.ReadSeeker) (*Workbook, error)
OpenReader reads an XLS file from a ReadSeeker.
Click to show internal directories.
Click to hide internal directories.